@@ -195,11 +195,25 @@ seahorse_widget_get_property (GObject *object, guint prop_id, GValue *value, GPa
 static void
 seahorse_widget_show_help (GtkWidget *widget, SeahorseWidget *swidget)
 {
-	//error check help
-	if (g_str_equal (swidget->name, "key-manager"))
-		gnome_help_display (PACKAGE, "toc", NULL);
-	else
-		gnome_help_display (PACKAGE, swidget->name, NULL);
+    GError *err = NULL;
+
+    if (g_str_equal (swidget->name, "key-manager"))
+        gnome_help_display (PACKAGE, NULL, &err);
+    else
+       gnome_help_display (PACKAGE, swidget->name, &err);
+
+    if (err != NULL) {
+        GtkWidget *dialog;
+
+        dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, 
+                                         GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
+                                         _("Could not display help: %s"),
+                                         err->message);
+        g_signal_connect (G_OBJECT (dialog), "response",
+                          G_CALLBACK (gtk_widget_destroy), NULL);
+        gtk_widget_show (dialog);
+        g_error_free (err);
+    }
 }
 
 /* Destroys widget */
@@ -276,6 +290,29 @@ seahorse_widget_new_allow_multiple (gchar *name, SeahorseContext *sctx)
 	return g_object_new (SEAHORSE_TYPE_WIDGET, "name", name, "ctx", sctx, NULL);
 }
 
+/**
+ * seahorse_widget_get_top
+ * @swidget: The seahorse widget
+ * 
+ * Return the top level widget in this seahorse widget
+ *
+ * Returns: The top level widget
+ **/
+GtkWidget*      
+seahorse_widget_get_top     (SeahorseWidget     *swidget)
+{
+    GtkWidget *widget = glade_xml_get_widget (swidget->xml, swidget->name);
+    g_return_val_if_fail (widget != NULL, NULL);
+    return widget;
+}
+
+void
+seahorse_widget_show (SeahorseWidget *swidget)
+{
+    GtkWidget *widget = glade_xml_get_widget (swidget->xml, swidget->name);
+    gtk_widget_show (widget);
+}
+ 
 /**
  * seahorse_widget_destroy:
  * @swidget: #SeahorseWidget to destroy
